MISSING_DATA = 'https://metadata.datadrivendiscovery.org/types/MissingData'
INTEGER = 'http://schema.org/Integer'
FLOAT = 'http://schema.org/Float'
TEXT = 'http://schema.org/Text'
BOOLEAN = 'http://schema.org/Boolean'
LATITUDE = 'http://schema.org/latitude'
LONGITUDE = 'http://schema.org/longitude'
DATE_TIME = 'http://schema.org/DateTime'
ADDRESS = 'http://schema.org/address'
ADMIN = 'http://schema.org/AdministrativeArea'
ID = 'http://schema.org/identifier'
CATEGORICAL = 'http://schema.org/Enumeration'
GEO_POINT = 'http://schema.org/GeoCoordinates'
GEO_POLYGON = 'http://schema.org/GeoShape'
